addpath('msf/');
addpath('functions/');

clear;
close('all');
figure;

color = 1;  % plot in color?
if color
    col1 = [ 25  25  25]/255;
    col2 = [0   115 230]/255;
    col3 = [255 128   0]/255;
    lin1 = 2;
    lin2 = 2;
    lin3 = 2;    
else
    col1 = [0.0 0.0 0.0];
    col2 = [0.4 0.4 0.4];
    col3 = [0.8 0.8 0.8];
    lin1 = 2;
    lin2 = 2;
    lin3 = 2;    
end

for sacLock = 0:1
    clear vpsRate*

    zfid = fopen('subjects.all','r');

    % dritical columns (2 = condition; 3 = target location)
    critcol = 2;
    critcol2 = 3;
    cc2v = [1 2 3]; % critial values of critical column 2 (choose [1 2 3] for main effects)
    [cStr1, cStr2, cStr3] = getcStr(critcol, cc2v);

    % settings
    velSD = 6;
    ntAll = 0;

    % time windows for the analyses
    ww = 50;            % window width
    sw = 1;             % step width
    if sacLock          % saccade locked analyses
        w1 = -600;      % time window start
        w2 = 0;         % time window end
    else                % go-locked analyses
        w1 = -300-ww/2; % time window start
        w2 = 1000+ww/2; % time window end
    end

    msDurAll = [];
    
    cnt = 1;
    s = 0;
    while cnt ~= 0
        [vpcode, cnt] = fscanf(zfid,'%s',1);
        if cnt ~= 0
            s = s+1;
            mat = [];

            msffile = sprintf('%s.msf1',vpcode);

            fprintf(1,'\n\n   loading %s ...',msffile);
            msf = load(msffile);

            for cond = 1:3   % 1 = Tar Top; 2 = Tar Right; 3 = Tar Left

                % generate matrix of all MS and trials in that condition
                idx = msf(:,critcol)==cond & ismember(msf(:,critcol2),cc2v) & msf(:,22)==1;
                cmsf = msf(idx,:);

                % total number of trials in that condition
                nt = length(unique(cmsf(:,1)));
                ntAll = ntAll + nt;
                fprintf(1,'\n\t%i\t trials with ',nt);

                % delete trials without saccades
                idx = find(cmsf(:,11)==0);
                cmsf(idx,:) = [];
                fprintf(1,'%i\tmicrosaccades', size(cmsf,1));

                % microsaccade onsets
                if sacLock
                    msOns = cmsf(:,11)-(cmsf(:,8)+cmsf(:,20));
                else
                    msOns = cmsf(:,11)-cmsf(:,6);
                end

                msDurAll = [msDurAll; cmsf(:,12)];
                
                % analyzing rate in moving time window
                scale = [];
                rateMS = [];
                mw = 0;
                for t = (w1+ww/2):sw:(w2-ww/2)
                    mw = mw + 1;

                    w_beg = t-ww/2;
                    w_end = t+ww/2;

                    idxMSwin = find(msOns>=w_beg & msOns<w_end);
                    rateMS(mw) = length(idxMSwin)/nt;

                    scale = [scale; t]; %#ok<*AGROW>
                end

                if cond == 1
                    vpsRate1(s,1:mw) = rateMS*1000/ww; %#ok<*SAGROW>
                elseif cond == 2
                    vpsRate2(s,1:mw) = rateMS*1000/ww;
                elseif cond == 3
                    vpsRate3(s,1:mw) = rateMS*1000/ww;
                end
            end
        end
    end
    fclose('all');

    % compute standard deviations
    sd1 = std(vpsRate1);
    sd2 = std(vpsRate2);
    sd3 = std(vpsRate3);

    % compute standard errors
    se1 = sd1/sqrt(size(vpsRate1,1)-1);
    se2 = sd2/sqrt(size(vpsRate2,1)-1);
    se3 = sd3/sqrt(size(vpsRate3,1)-1);

    if sacLock == 0
        a1 = axes('Position',[0.05 0.15 .6 .8]);
        axes(a1);
        xlabel('Time [ms]','fontsize',20);
        ylabel('Microsaccade rate [1/sec]','fontsize',20);
        xTicks = w1+ww/2:100:w2-ww/2;
    else
        a2 = axes('Position',[0.685 0.15 .2769 .8]);
        axes(a2);
        xlabel('Time to saccade onset [ms]','fontsize',20);
        set(a2,'YAxisLocation','Right');
        xTicks = w1:100:w2;
    end
    ylim([0 2.1]);
    xlim([w1 w2]);
    set(gca,'xgrid','on','Layer','top','fontsize',20,'ytick',0:0.2:2,'xtick',xTicks);
    hold on;
    p1 = plot(scale,mean(vpsRate1),'-','linewidth',lin1,'color',col1);
    p2 = plot(scale,mean(vpsRate2),'-','linewidth',lin2,'color',col2);
    p3 = plot(scale,mean(vpsRate3),'-','linewidth',lin3,'color',col3);

    if sacLock == 0
        legend([p1,p2,p3],'Visual-Static','Visual-Change','Memory',2);
    end
end

set(gcf,'Position',[213 472 1321 384]);

fprintf(1,'\n\nOK!\n');
