addpath('msf/');
addpath('functions/');

clear;
close('all');
figure;

color = 1;  % plot in color?
if color
    col1 = [ 25  25  25]/255;
    col2 = [0   115 230]/255;
    col3 = [255 128   0]/255;
    col1o= [219 219 219]/255;
    col2o= [198 226 255]/255;
    col3o= [255 209 164]/255;
else
    col1 = [0.3 0.3 0.3];
    col1o= [0.8 0.8 0.8];
    col2 = [0.3 0.3 0.3];
    col2o= [0.8 0.8 0.8];
    col3 = [0.3 0.3 0.3];
    col3o= [0.8 0.8 0.8];
end


zfid = fopen('subjects.all','r');

offLock= 1; % lock to MS offest insted of onset?

% Bedingungen (2 = condition; 3 = target location)
critcol = 2;
critcol2 = 3;
cc2v = [1 2 3]; % critial values of critical column 2 (choose [1 2 3] for main effects)
cStr1 = 'Visual-Static';
cStr2 = 'Visual-Change';
cStr3 = 'Memory';
tStr1 = 'Pre-target';
tStr2 = 'Target';
tStr3 = 'Pre-saccade';

% time windows for the analyses
tw0 = [-100    0];
tw1 = [ 130  230];
tw2 = [ 900 1000];

ntAll = 0;
cnt = 1;
s = 0;
while cnt ~= 0
    [vpcode, cnt] = fscanf(zfid,'%s',1);
    if cnt ~= 0
        s = s+1;
        mat = [];
        
        msffile = sprintf('%s.msf1',vpcode);
        
        fprintf(1,'\n\tloading %s ...',vpcode);
        msf = load(msffile);
        fprintf(1,' processing');
        
        for cond = 1:3   % e.g., for critcol = 3: 1 = Tar Top; 2 = Tar Right; 3 = Tar Left
            % generate matrix of all MS and trials in that condition
            i = find(msf(:,critcol)==cond & ismember(msf(:,critcol2),cc2v) & msf(:,22)==1);
            cmsf = msf(i,:);
            
            % microsaccade onsets
            msOns = cmsf(:,11)-cmsf(:,6);
            if offLock
                msOns = msOns+cmsf(:,12);
            end
            % saccadic reaction times
            rts   = cmsf(:,20);
            
            % Index aller Mikrosakkaden, die in Zeitfenster tw* vorkommen
            iMStw0 = find(msOns>=tw0(1) & msOns<=tw0(2));
            iMStw1 = find(msOns>=tw1(1) & msOns<=tw1(2));
            iMStw2 = find(msOns>=tw2(1) & msOns<=tw2(2));
            
            % trials corresponding to inds
            tMS1tw0 = cmsf(iMStw0,1);
            tMS1tw1 = cmsf(iMStw1,1);
            tMS1tw2 = cmsf(iMStw2,1);
            [tMS1tw0 iMS1tw0] = unique(tMS1tw0);
            [tMS1tw1 iMS1tw1] = unique(tMS1tw1);
            [tMS1tw2 iMS1tw2] = unique(tMS1tw2);
            iMS1tw0 = iMStw0(iMS1tw0);
            iMS1tw1 = iMStw1(iMS1tw1);
            iMS1tw2 = iMStw2(iMS1tw2);
            [tMS0tw0 iMS0tw0] = setdiff(cmsf(:,1),tMS1tw0);
            [tMS0tw1 iMS0tw1] = setdiff(cmsf(:,1),tMS1tw1);
            [tMS0tw2 iMS0tw2] = setdiff(cmsf(:,1),tMS1tw2);
            
            % All trials in which ms occur in time window tw1, but when
            % certain conditions apply
            tMS1tw1MS0tw2 = setdiff(tMS1tw1,tMS1tw2);
            [g, iMS1tw1MS0tw2] = intersect(cmsf(:,1),tMS1tw1MS0tw2);
            tMS0tw1MS1tw2 = setdiff(tMS1tw2,tMS1tw1);
            [g, iMS0tw1MS1tw2] = intersect(cmsf(:,1),tMS0tw1MS1tw2);
            [tMS1tw1MS1tw2, iMS1tw1MS1tw2] = intersect(tMS1tw2,tMS1tw1);
            [tMS0tw1MS0tw2, iMS0tw1MS0tw2] = setdiff(cmsf(:,1),union(tMS1tw1,tMS1tw2));
            
            if cond == 1
                mCoVi1(s) = mean(cmsf(find(cmsf(:,2)==1 & cmsf(:,10)<=1),20));

                rtMS1tw0vps1(s) = nanmean(rts(iMS1tw0));
                rtMS0tw0vps1(s) = nanmean(rts(iMS0tw0));;
                rtMS1tw1vps1(s) = nanmean(rts(iMS1tw1));
                rtMS0tw1vps1(s) = nanmean(rts(iMS0tw1));
                rtMS1tw2vps1(s) = nanmean(rts(iMS1tw2));
                rtMS0tw2vps1(s) = nanmean(rts(iMS0tw2));
                rtMS1tw1MS1tw2vps1(s) = nanmean(rts(iMS1tw1MS1tw2));
                rtMS1tw1MS0tw2vps1(s) = nanmean(rts(iMS1tw1MS0tw2));
                rtMS0tw1MS1tw2vps1(s) = nanmean(rts(iMS0tw1MS1tw2));
                rtMS0tw1MS0tw2vps1(s) = nanmean(rts(iMS0tw1MS0tw2));
                
                ntMS1tw0vps1(s) = length(find(rts(iMS1tw0))>0);
                ntMS0tw0vps1(s) = length(find(rts(iMS0tw0))>0);
                ntMS1tw1vps1(s) = length(find(rts(iMS1tw1))>0);
                ntMS0tw1vps1(s) = length(find(rts(iMS0tw1))>0);
                ntMS1tw2vps1(s) = length(find(rts(iMS1tw2))>0);
                ntMS0tw2vps1(s) = length(find(rts(iMS0tw2))>0);
            elseif cond == 2
                mCoVi2(s) = mean(cmsf(find(cmsf(:,2)==2 & cmsf(:,10)<=1),20));

                rtMS1tw0vps2(s) = nanmean(rts(iMS1tw0));
                rtMS0tw0vps2(s) = nanmean(rts(iMS0tw0));
                rtMS1tw1vps2(s) = nanmean(rts(iMS1tw1));
                rtMS0tw1vps2(s) = nanmean(rts(iMS0tw1));
                rtMS1tw2vps2(s) = nanmean(rts(iMS1tw2));
                rtMS0tw2vps2(s) = nanmean(rts(iMS0tw2));
                rtMS1tw1MS1tw2vps2(s) = nanmean(rts(iMS1tw1MS1tw2));
                rtMS1tw1MS0tw2vps2(s) = nanmean(rts(iMS1tw1MS0tw2));
                rtMS0tw1MS1tw2vps2(s) = nanmean(rts(iMS0tw1MS1tw2));
                rtMS0tw1MS0tw2vps2(s) = nanmean(rts(iMS0tw1MS0tw2));
                
                ntMS1tw0vps2(s) = length(find(rts(iMS1tw0))>0);
                ntMS0tw0vps2(s) = length(find(rts(iMS0tw0))>0);
                ntMS1tw1vps2(s) = length(find(rts(iMS1tw1))>0);
                ntMS0tw1vps2(s) = length(find(rts(iMS0tw1))>0);
                ntMS1tw2vps2(s) = length(find(rts(iMS1tw2))>0);
                ntMS0tw2vps2(s) = length(find(rts(iMS0tw2))>0);
            elseif cond == 3
                mCoMem(s) = mean(cmsf(find(cmsf(:,2)==3 & cmsf(:,10)<=1),20));

                rtMS1tw0vps3(s) = nanmean(rts(iMS1tw0));
                rtMS0tw0vps3(s) = nanmean(rts(iMS0tw0));
                rtMS1tw1vps3(s) = nanmean(rts(iMS1tw1));
                % fprintf(1,'\n%i',length(find(rts(iMS1tw1))>0));
                rtMS0tw1vps3(s) = nanmean(rts(iMS0tw1));
                rtMS1tw2vps3(s) = nanmean(rts(iMS1tw2));
                rtMS0tw2vps3(s) = nanmean(rts(iMS0tw2));
                rtMS1tw1MS1tw2vps3(s) = nanmean(rts(iMS1tw1MS1tw2));
                rtMS1tw1MS0tw2vps3(s) = nanmean(rts(iMS1tw1MS0tw2));
                rtMS0tw1MS1tw2vps3(s) = nanmean(rts(iMS0tw1MS1tw2));
                rtMS0tw1MS0tw2vps3(s) = nanmean(rts(iMS0tw1MS0tw2));
                
                ntMS1tw0vps3(s) = length(find(rts(iMS1tw0))>0);
                ntMS0tw0vps3(s) = length(find(rts(iMS0tw0))>0);
                ntMS1tw1vps3(s) = length(find(rts(iMS1tw1))>0);
                ntMS0tw1vps3(s) = length(find(rts(iMS0tw1))>0);
                ntMS1tw2vps3(s) = length(find(rts(iMS1tw2))>0);
                ntMS0tw2vps3(s) = length(find(rts(iMS0tw2))>0);
            end
        end
    end
end


% compute means, std, ste, and differences
for cond = 1:3
    for tw = 0:2
        evalD = sprintf('tw%iD%i = nanmean(rtMS1tw%ivps%i-rtMS0tw%ivps%i);',tw,cond,tw,cond,tw,cond);
        eval(evalD);
        switch tw
        case 0
            alpha = 0.05;
        case 1
            alpha = 0.10;
        case 2
            alpha = 0.10;
        end
            alpha = 0.05;
        evalC = sprintf('[h,p,ci] = ttest(rtMS1tw%ivps%i-rtMS0tw%ivps%i,0,alpha);',tw,cond,tw,cond);
        eval(evalC);
        fin = ci(isfinite(ci));
        cis(tw+1,cond) = abs(mean(fin)-fin(1));
    end
end


aBase = axes('Position',[0 0 1 1],'Visible','Off');

axPos = [0.07 0.14 0.29  0.85;
         0.38 0.14 0.29  0.85;
         0.69 0.14 0.29  0.85];

for a = 1:size(axPos,1)
    ax(a) = axes('Position',axPos(a,:));
end

for tw = 0:2
    axes(ax(tw+1));
    set(gca,'Fontsize',20,'xtick',1:1:3,'ytick',0:10:300,'xticklabel',{'Visual-static' 'Visual-change' 'Memory'});%,'yticklabel',0:10:300);
    ylim([201 295]);
    xlim([0.5 3.5]);
    hold on;
    ms = 0;
    eval(sprintf('m%i1 = nanmean(rtMS%itw%ivps1);',ms,ms,tw));
    eval(sprintf('m%i2 = nanmean(rtMS%itw%ivps2);',ms,ms,tw));
    eval(sprintf('m%i3 = nanmean(rtMS%itw%ivps3);',ms,ms,tw));
    eval(sprintf('s%i1 = nanstd(rtMS%itw%ivps1)/sqrt(sum(~isnan(rtMS%itw%ivps1)));',ms,ms,tw,ms,tw));
    eval(sprintf('s%i2 = nanstd(rtMS%itw%ivps2)/sqrt(sum(~isnan(rtMS%itw%ivps2)));',ms,ms,tw,ms,tw));
    eval(sprintf('s%i3 = nanstd(rtMS%itw%ivps3)/sqrt(sum(~isnan(rtMS%itw%ivps3)));',ms,ms,tw,ms,tw));
    ms = 1;
    eval(sprintf('m%i1 = nanmean(rtMS%itw%ivps1);',ms,ms,tw));
    eval(sprintf('m%i2 = nanmean(rtMS%itw%ivps2);',ms,ms,tw));
    eval(sprintf('m%i3 = nanmean(rtMS%itw%ivps3);',ms,ms,tw));
    eval(sprintf('s%i1 = nanstd(rtMS%itw%ivps1)/sqrt(sum(~isnan(rtMS%itw%ivps1)));',ms,ms,tw,ms,tw));
    eval(sprintf('s%i2 = nanstd(rtMS%itw%ivps2)/sqrt(sum(~isnan(rtMS%itw%ivps2)));',ms,ms,tw,ms,tw));
    eval(sprintf('s%i3 = nanstd(rtMS%itw%ivps3)/sqrt(sum(~isnan(rtMS%itw%ivps3)));',ms,ms,tw,ms,tw));
    x = [1 2 3];
    h = bar(x,[m01 m02 m03;m11 m12 m13]','grouped');
    
    switch tw
        case 0
        c1 = col1;
        c2 = col1o;
        ylabel('SRT [ms]');
        case 1
        c1 = col2;
        c2 = col2o;
        xlabel('Condition');
        set(gca,'yticklabel','');
        case 2
        c1 = col3;
        c2 = col3o;
        set(gca,'yticklabel','');
    end
    child = get(gca,'children');
    set(child(1),'Facecolor',c1);
    set(child(2),'Facecolor',c2);

    e = barerrorbar(gca,[s01 s02 s03;s11 s12 s13]');
    text(0.6,290,eval(sprintf('tStr%i',tw+1)),'Fontsize',24);
    hold off;
end
set(gcf,'position',[255 410 1210 449])

fprintf(1,'\n\nOK!!\n');
