addpath('msf/');
addpath('functions/');

clear;
close('all');

color = 1;
if color
    col1 = [ 25  25  25]/255;
    col2 = [0   115 230]/255;
    col3 = [255 128   0]/255;
    col1c= [219 219 219]/255;
    col2c= [198 226 255]/255;
    col3c= [255 209 164]/255;
else
    col1 = [0.3 0.3 0.3];
    col1c= [0.8 0.8 0.8];
    col2 = [0.3 0.3 0.3];
    col2c= [0.8 0.8 0.8];
    col3 = [0.3 0.3 0.3];
    col3c= [0.8 0.8 0.8];
end

zfid = fopen('subjects.all','r');

% switches
surDat = 0; % RTs randomly redistributed
offLock= 0; % lock to MS offest insted of onset?

% critical columns (2 = condition; 3 = target location)
critcol = 2;
critcol2 = 3;
cc2v = [1 2 3]; % critial values of critical column 2 (choose [1 2 3] for main effects)
[cStr1, cStr2, cStr3] = getcStr(critcol, cc2v);

% time windows for the analyses
ww = 100;
sw = 10;
w1 = 0;
w2 = 1070;

ntAll = 0;
cnt = 1;
s = 0;
while cnt ~= 0
    [vpcode, cnt] = fscanf(zfid,'%s',1);
    if cnt ~= 0
        s = s+1;
        mat = [];
        
        msffile = sprintf('%s.msf1',vpcode);
        
        fprintf(1,'\n\n   loading %s ...',vpcode);
        msf = load(msffile);
        
        for cond = 1:3   % 1 = Tar Top; 2 = Tar Right; 3 = Tar Left
            % generate matrix of all MS and trials in that condition (& if
            % only one targeting saccade)
            idx = msf(:,critcol)==cond & ismember(msf(:,critcol2),cc2v) & msf(:,22)==1;
            cmsf = msf(idx,:);

            % total number of trials in that condition
            nt = length(unique(cmsf(:,1)));
            ntAll = ntAll + nt;
            fprintf(1,'\n\t%i\t trials with ',nt);
            
            % delete trials without saccades
            idx = find(cmsf(:,11)==0);
            cmsf(idx,:) = [];
            fprintf(1,'%i\t microsaccades', size(cmsf,1));
            
            % response latencies
            rts = cmsf(:,20);
            if surDat
                rts = rts(randperm(length(rts)));
            end
            
            % microsaccade onsets
            msOns = cmsf(:,11)-cmsf(:,6);
            if offLock
                msOns = msOns+cmsf(:,12);
            end

            % analyzing rate in moving time window
            scale = [];
            for t = (w1+ww/2):sw:(w2-ww/2)
                scale = [scale; t];
                
                % Index of all microsaccades in that time window
                idxMSwin = find(msOns>=t-ww/2 & msOns<t+ww/2);
                
                % find corresponding RTs
                trialsMS1 = cmsf(idxMSwin,1);
                [trialsMS1 idxMS1] = unique(trialsMS1);
                idxMS1 = idxMSwin(idxMS1);
                [trialsMS0 idxMS0] = setdiff(cmsf(:,1),trialsMS1);
                
                rtMS1(length(scale)) = nanmean(rts(idxMS1));
                rtMS0(length(scale)) = nanmean(rts(idxMS0));
                ntMS1(length(scale)) = sum(~isnan(rts(idxMS1)));
                ntMS0(length(scale)) = sum(~isnan(rts(idxMS0)));
            end
            
            if cond == 1
                rtMS1vps1(s,1:length(scale)) = rtMS1;
                rtMS0vps1(s,1:length(scale)) = rtMS0;
                ntMS1vps1(s,1:length(scale)) = ntMS1;
                ntMS0vps1(s,1:length(scale)) = ntMS0;
            elseif cond == 2
                rtMS1vps2(s,1:length(scale)) = rtMS1;
                rtMS0vps2(s,1:length(scale)) = rtMS0;
                ntMS1vps2(s,1:length(scale)) = ntMS1;
                ntMS0vps2(s,1:length(scale)) = ntMS0;
            elseif cond == 3
                rtMS1vps3(s,1:length(scale)) = rtMS1;
                rtMS0vps3(s,1:length(scale)) = rtMS0;
                ntMS1vps3(s,1:length(scale)) = ntMS1;
                ntMS0vps3(s,1:length(scale)) = ntMS0;
            end
        end
    end 
end

alpha = 0.05;
for tt = 1:length(scale)
    [h1(tt), p1(tt), ci1(tt,1:2)] = ttest(rtMS1vps1(:,tt),rtMS0vps1(:,tt),alpha);
    [h2(tt), p2(tt), ci2(tt,1:2)] = ttest(rtMS1vps2(:,tt),rtMS0vps2(:,tt),alpha);
    [h3(tt), p3(tt), ci3(tt,1:2)] = ttest(rtMS1vps3(:,tt),rtMS0vps3(:,tt),alpha);
end
ih1 = find(h1==1);
ih2 = find(h2==1);
ih3 = find(h3==1);

figure
aBase = axes('Position',[0 0 1 1],'Visible','Off');

axPos = [0.15 0.7 0.28  0.27;
         0.15 0.4 0.28  0.27;
         0.15 0.1 0.28  0.27;
         0.45 0.7 0.518 0.27;
         0.45 0.4 0.518 0.27;
         0.45 0.1 0.518 0.27];

for a = 1:size(axPos,1)
    ax(a) = axes('Position',axPos(a,:));
end

axes(aBase);
text((axPos(6,1)+axPos(6,3)+axPos(1,1))/2,.04,'Time [ms]','HorizontalAlignment','center','Fontsize',18);

% Plots tw1
% Plot 1: Cond 1
axes(ax(1))
hold on;
xlim([ww/2 250]);
ylim([-30 90]);
set(gca,'xgrid','on','Layer','top','Fontsize',18,'ytick',-100:20:100,...
    'xtick',0:100:1100,'xticklabel',{});

d = nanmean(rtMS1vps1-rtMS0vps1);
e = fill([scale' vecinv(scale)'],[(ci1(:,1)') vecinv(ci1(:,2)')],[.5 .5 .5],'facecolor',col1c,'linestyle','none');
plot([w1 w2],[0 0],'k-');
p = plot(scale,d,'k-','linewidth',2,'color',col1);
text(60,70,'Visual-Static','Fontsize',18);

% Plot 2: Cond 2
axes(ax(2))
hold on;
xlim([ww/2 250]);
ylim([-30 90]);
set(gca,'xgrid','on','Layer','top','Fontsize',18,'ytick',-100:20:100,...
    'xtick',0:100:1100,'xticklabel',{});
ylabel('{\it\DeltaSRT} [ms]','Fontsize',18);

d = nanmean(rtMS1vps2-rtMS0vps2);
e = fill([scale' vecinv(scale)'],[(ci2(:,1)') vecinv(ci2(:,2)')],[.5 .5 .5],'facecolor',col2c,'linestyle','none');
plot([w1 w2],[0 0],'k-');
p = plot(scale,d,'k-','linewidth',2,'color',col2);
text(60,70,'Visual-Change','Fontsize',18);

% Plot 1: Cond 3
axes(ax(3))
hold on;
xlim([ww/2 250]);
ylim([-30 90]);
set(gca,'xgrid','on','Layer','top','Fontsize',18,'ytick',-100:20:100,...
    'xtick',0:100:1100);

d = nanmean(rtMS1vps3-rtMS0vps3);
e = fill([scale' vecinv(scale)'],[(ci3(:,1)') vecinv(ci3(:,2)')],[.5 .5 .5],'facecolor',col3c,'linestyle','none');
plot([w1 w2],[0 0],'k-');
p = plot(scale,d,'k-','linewidth',2,'color',col3);
text(60,70,'Memory','Fontsize',18);

% Plots tw2
% Plot 1: Cond 1
axes(ax(4))
hold on;
xlim([680 w2-ww/2]);
ylim([-30 90]);
set(gca,'xgrid','on','Layer','top','Fontsize',18,'ytick',-100:20:100,'yticklabel',{},...
    'xtick',0:100:1100,'xticklabel',{},'YAxisLocation','right');

d = nanmean(rtMS1vps1-rtMS0vps1);
e = fill([scale' vecinv(scale)'],[(ci1(:,1)') vecinv(ci1(:,2)')],[.5 .5 .5],'facecolor',col1c,'linestyle','none');
plot([w1 w2],[0 0],'k-');
p = plot(scale,d,'k-','linewidth',2,'color',col1);

% Plot 2: Cond 2
axes(ax(5))
hold on;
xlim([680 w2-ww/2]);
ylim([-30 90]);
set(gca,'xgrid','on','Layer','top','Fontsize',18,'ytick',-100:20:100,'yticklabel',{},...
    'xtick',0:100:1100,'xticklabel',{},'YAxisLocation','right');

d = nanmean(rtMS1vps2-rtMS0vps2);
e = fill([scale' vecinv(scale)'],[(ci2(:,1)') vecinv(ci2(:,2)')],[.5 .5 .5],'facecolor',col2c,'linestyle','none');
plot([w1 w2],[0 0],'k-');
p = plot(scale,d,'k-','linewidth',2,'color',col2);

% Plot 1: Cond 3
axes(ax(6))
hold on;
xlim([680 w2-ww/2]);
ylim([-30 90]);
set(gca,'xgrid','on','Layer','top','Fontsize',18,'ytick',-100:20:100,'yticklabel',{},...
    'xtick',0:100:1100,'YAxisLocation','right');

d = nanmean(rtMS1vps3-rtMS0vps3);
e = fill([scale' vecinv(scale)'],[(ci3(:,1)') vecinv(ci3(:,2)')],[.5 .5 .5],'facecolor',col3c,'linestyle','none');
plot([w1 w2],[0 0],'k-');
p = plot(scale,d,'k-','linewidth',2,'color',col3);

set(gcf,'Position',[560 281 473 603]);

fprintf(1,'\n\nOK!!!\n');

